sfs.plot
========

.. automodule:: sfs.plot

   
   
   .. rubric:: Functions

   .. autosummary::
   
      add_colorbar
      level
      loudspeaker_2d
      loudspeaker_3d
      particles
      reference_2d
      secondarysource_2d
      soundfield
      vectors
      virtualsource_2d
   
   

   
   
   

   
   
   